pub trait ObjFloat:
Copy
+ Display
+ FromStr
+ PartialEq {
// Required methods
fn fract(self) -> Self;
fn zero() -> Self;
// Provided method
fn is_zero_fract(self) -> bool { ... }
}Expand description
Trait for floating point types that can be used in OBJ files. This allows the library to work with both f32 and f64 precision.
Required Methods
Provided Methods
Sourcefn is_zero_fract(self) -> bool
fn is_zero_fract(self) -> bool
Returns true if the fractional part is zero
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.